@@ -1,4 +1,4 @@
-/* $Id: messages.h,v 1.29 2012/05/28 10:56:27 imilh Exp $ */
+/* $Id: messages.h,v 1.33 2012/11/25 09:13:38 imilh Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -56,8 +56,6 @@
 #define MSG_DONT_HAVE_RIGHTS "You don't have enough rights for this operation."
 
 /* actions.c */
-#define MSG_PROCEED_YES "proceed ? [Y/n] "
-#define MSG_PROCEED_NO "proceed ? [y/N] "
 #define MSG_REMOVING "removing %s...\n"
 #define MSG_DOWNLOAD_PKGS "downloading packages...\n"
 #define MSG_PKG_NO_REPO "%s has no associated repository"
@@ -74,8 +72,8 @@
 	"%s (to be installed) conflicts with installed package %s.\n"
 #define MSG_NOTHING_TO_DO "nothing to do.\n"
 #define MSG_REQT_MISSING "the following packages have unmet requirements: %s\n\n"
-#define MSG_NO_CACHE_SPACE "%s has not enough space for download\n"
-#define MSG_NO_INSTALL_SPACE "%s has not enough space for installation\n"
+#define MSG_NO_CACHE_SPACE "%s does not have enough space for download, (%s required but only %s are available)\n"
+#define MSG_NO_INSTALL_SPACE "%s does not have enough space for installation (%s required but only %s are available)\n"
 #define MSG_PKGS_TO_UPGRADE "%d packages to be upgraded: %s\n"
 #define MSG_PKGS_TO_REMOVE "%d packages to be removed: %s\n"
 #define MSG_NOTHING_TO_UPGRADE "nothing to upgrade.\n"
@@ -88,6 +86,7 @@
 #define MSG_PKGS_TO_DELETE "%d packages to delete: %s\n"
 #define MSG_NO_PKGS_TO_DELETE "no packages to delete\n"
 #define MSG_EMPTY_KEEP_LIST "empty non-autoremovable package list"
+#define MSG_EMPTY_NOKEEP_LIST "empty autoremovable package list"
 #define MSG_EMPTY_AVAIL_PKGLIST "empty available packages list"
 #define MSG_UPGRADE_NEED_REMOVE "this upgrade needs package removal\n"
 #define MSG_PKG_INSTALL_LOGGING_TO "pkg_install error log can be found in %s\n"
@@ -112,6 +111,7 @@ in order to remove packages from the autoremove list, flag those with the `keep'
 #define MSG_ALL_KEEP_PKGS "all packages are marked as \"keepable\"\n."
 #define MSG_AUTOREMOVE_PKGS "%d packages to be autoremoved: %s\n"
 #define MSG_MARK_PKG_KEEP "%s is marked as non-autoremovable\n"
+#define MSG_MARK_PKG_NOKEEP "%s is marked as autoremovable\n"
 #define MSG_MARKING_PKG_KEEP "marking %s as non auto-removable\n"
 #define MSG_UNMARKING_PKG_KEEP "marking %s as auto-removable\n"
 #define MSG_NO_ORPHAN_DEPS "no orphan dependencies found.\n"
